@@ -331,14 +331,7 @@ public class FormatData_kln extends ListResourceBundle {
             { "japanese.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_generic_TimePatterns },
             { "java.time.japanese.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "japanese.DatePatterns",
-                new String[] {
-                    "EEEE, d MMMM yyyy GGGG",
-                    "d MMMM yyyy GGGG",
-                    "d MMM y GGGG",
-                    "dd/MM/y G",
-                }
-            },
+            { "japanese.DatePatterns", metaValue_generic_DatePatterns },
             { "japanese.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
             { "japanese.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
             { "japanese.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
