@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -317,14 +317,7 @@ public class FormatData_rof extends ListResourceBundle {
             { "japanese.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_generic_TimePatterns },
             { "java.time.japanese.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "japanese.DatePatterns",
-                new String[] {
-                    "EEEE, d MMMM yyyy GGGG",
-                    "d MMMM yyyy GGGG",
-                    "d MMM y GGGG",
-                    "dd/MM/y G",
-                }
-            },
+            { "japanese.DatePatterns", metaValue_generic_DatePatterns },
             { "japanese.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
             { "japanese.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
             { "japanese.DateFormatItem.MMMMEd", metaValue_generic_DateFormatItem_MMMMEd },
